__copyright__ = "Copyright © Stichting SciPost (SciPost Foundation)"
__license__ = "AGPL v3"


from django.urls import include, path
from django.views.generic import TemplateView

from apimail.api import views as apiviews
from . import views


app_name = 'apimail'

urlpatterns = [

    # API

    path('api/', include([

        path( # /mail/api/accounts
            'accounts',
            apiviews.EmailAccountListAPIView.as_view(),
            name='accounts'
        ),
        path( # /mail/api/user_account_accesses
            'user_account_accesses',
            apiviews.UserEmailAccountAccessListAPIView.as_view(),
            name='user_account_accesses'
        ),
        path( # /mail/api/events
            'events',
            apiviews.EventListAPIView.as_view(),
            name='api_event_list'
        ),
        path( # /mail/api/event/<uuid>
            'event/<uuid:uuid>',
            apiviews.EventRetrieveAPIView.as_view(),
            name='api_event_retrieve'
        ),
        path( # /mail/api/stored_messages
            'stored_messages',
            apiviews.StoredMessageListAPIView.as_view(),
            name='api_stored_message_list'
        ),
        path( # /mail/api/stored_message/<uuid>
            'stored_message/<uuid:uuid>',
            apiviews.StoredMessageRetrieveAPIView.as_view(),
            name='api_stored_message_retrieve'
        ),
        path( # /mail/api/stored_message/<uuid>/mark_as_read
            'stored_message/<uuid:uuid>/mark_as_read',
            apiviews.StoredMessageUpdateReadAPIView.as_view(),
            name='api_stored_message_mark_as_read'
        ),
        path( # /mail/api/stored_message/<uuid>/tag
            'stored_message/<uuid:uuid>/tag',
            apiviews.StoredMessageUpdateTagAPIView.as_view(),
            name='api_stored_message_tag'
        ),
        path( # /mail/api/user_tags
            'user_tags',
            apiviews.UserTagListAPIView.as_view(),
            name='api_user_tags'
        ),
    ])),


    # User views

    path( # /mail/messages
        'messages',
        TemplateView.as_view(template_name='apimail/message_list.html'),
        name='message_list'
    ),
    path( # /mail/message/<uuid>/attachments/<int>
        'message/<uuid:uuid>/attachments/<int:pk>',
        views.attachment_file,
        name='message_attachment'
    ),
    path( # /mail/message/compose
        'message/compose',
        TemplateView.as_view(template_name='apimail/message_compose.html'),
        name='message_compose'
    ),
]
